@@ -1,9 +1,5 @@
 <?php
 
-// Load configuration
-$config = new GitList\Config('config.ini');
-$config->set('git', 'repositories', rtrim($config->get('git', 'repositories'), DIRECTORY_SEPARATOR) . DIRECTORY_SEPARATOR);
-
 // Startup and configure Silex application
 $app = new GitList\Application($config, __DIR__);
 
