@@ -20,22 +20,23 @@ $(function () {
         });
     }
 
-    if ($('#readme-content').length) {
+    if ($('#md-content').length) {
         var converter = new Showdown.converter();
-        $('#readme-content').html(converter.makeHtml($('#readme-content').text()));
+        $('#md-content').html(converter.makeHtml($('#md-content').text()));
     }
 
     function paginate() {
         var $pager = $('.pager');
+
         $pager.find('.next a').one('click', function (e) {
             e.preventDefault();
-            $(this).css('pointer-events', 'none');
             $.get(this.href, function (html) {
                 $pager.after(html);
                 $pager.remove();
                 paginate();
             });
         });
+
         $pager.find('.previous').remove();
     }
     paginate();
